==> ejc-metadata-api-3.0.0-20200420.035740-3-sources.jar: com/ejianc/foundation/metadata/vo/ReferVO.java <==
package com.ejianc.foundation.metadata.vo;

import java.io.Serializable;

/**
 * 参照注册数据对象
 * 
 *
 */
public class ReferVO implements Serializable{
	private static final long serialVersionUID = 1L;
	private String id;
	private String refCode;
	private String refName;
	private String refType;
	private String dataurl;
	private String operateurl;
	private String treerelyurl;
	private String gridrefcode;
	private String relyfield;
	private String orderfield;
	private String groupId;
	private String memo;
	private String idField;
	private String codeField;
	private String nameField;
	private String operatefield;
	private Boolean enableBaseUrl;

	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	public String getRefCode() {
		return refCode;
	}

	public void setRefCode(String refCode) {
		this.refCode = refCode;
	}

	public String getRefName() {
		return refName;
	}

	public void setRefName(String refName) {
		this.refName = refName;
	}

	public String getRefType() {
		return refType;
	}

	public void setRefType(String refType) {
		this.refType = refType;
	}

	public String getDataurl() {
		return dataurl;
	}

	public void setDataurl(String dataurl) {
		this.dataurl = dataurl;
	}

	public String getOperateurl() {
		return operateurl;
	}

	public void setOperateurl(String operateurl) {
		this.operateurl = operateurl;
	}

	public String getTreerelyurl() {
		return treerelyurl;
	}

	public void setTreerelyurl(String treerelyurl) {
		this.treerelyurl = treerelyurl;
	}

	public String getGridrefcode() {
		return gridrefcode;
	}

	public void setGridrefcode(String gridrefcode) {
		this.gridrefcode = gridrefcode;
	}

	public String getRelyfield() {
		return relyfield;
	}

	public void setRelyfield(String relyfield) {
		this.relyfield = relyfield;
	}

	public String getOrderfield() {
		return orderfield;
	}

	public void setOrderfield(String orderfield) {
		this.orderfield = orderfield;
	}

	public String getGroupId() {
		return groupId;
	}

	public void setGroupId(String groupId) {
		this.groupId = groupId;
	}

	public String getMemo() {
		return memo;
	}

	public void setMemo(String memo) {
		this.memo = memo;
	}

	public String getIdField() {
		return idField;
	}

	public void setIdField(String idField) {
		this.idField = idField;
	}

	public String getCodeField() {
		return codeField;
	}

	public void setCodeField(String codeField) {
		this.codeField = codeField;
	}

	public String getNameField() {
		return nameField;
	}

	public void setNameField(String nameField) {
		this.nameField = nameField;
	}

	public String getOperatefield() {
		return operatefield;
	}

	public void setOperatefield(String operatefield) {
		this.operatefield = operatefield;
	}

	public Boolean getEnableBaseUrl() {
		return enableBaseUrl;
	}

	public void setEnableBaseUrl(Boolean enableBaseUrl) {
		this.enableBaseUrl = enableBaseUrl;
	}
	

}

==> ejc-metadata-api-3.0.0-20231222.030302-293-sources.jar: com/ejianc/foundation/metadata/vo/ReferVO.java <==
package com.ejianc.foundation.metadata.vo;

import java.io.Serializable;

/**
 * 参照注册数据对象
 * 
 *
 */
public class ReferVO implements Serializable{
	private static final long serialVersionUID = 1L;
	private Long id;
	private String refCode;
	private String refName;
	private String refType;
	private String dataurl;
	private String operateurl;
	private String treerelyurl;
	private String gridrefcode;
	private String relyfield;
	private String orderfield;
	private String groupId;
	private String memo;
	private String idField;
	private String codeField;
	private String nameField;
	private String operatefield;
	private Boolean enableBaseUrl;

	public Long getId() {
		return id;
	}

	public void setId(Long l) {
		this.id = l;
	}

	public String getRefCode() {
		return refCode;
	}

	public void setRefCode(String refCode) {
		this.refCode = refCode;
	}

	public String getRefName() {
		return refName;
	}

	public void setRefName(String refName) {
		this.refName = refName;
	}

	public String getRefType() {
		return refType;
	}

	public void setRefType(String refType) {
		this.refType = refType;
	}

	public String getDataurl() {
		return dataurl;
	}

	public void setDataurl(String dataurl) {
		this.dataurl = dataurl;
	}

	public String getOperateurl() {
		return operateurl;
	}

	public void setOperateurl(String operateurl) {
		this.operateurl = operateurl;
	}

	public String getTreerelyurl() {
		return treerelyurl;
	}

	public void setTreerelyurl(String treerelyurl) {
		this.treerelyurl = treerelyurl;
	}

	public String getGridrefcode() {
		return gridrefcode;
	}

	public void setGridrefcode(String gridrefcode) {
		this.gridrefcode = gridrefcode;
	}

	public String getRelyfield() {
		return relyfield;
	}

	public void setRelyfield(String relyfield) {
		this.relyfield = relyfield;
	}

	public String getOrderfield() {
		return orderfield;
	}

	public void setOrderfield(String orderfield) {
		this.orderfield = orderfield;
	}

	public String getGroupId() {
		return groupId;
	}

	public void setGroupId(String groupId) {
		this.groupId = groupId;
	}

	public String getMemo() {
		return memo;
	}

	public void setMemo(String memo) {
		this.memo = memo;
	}

	public String getIdField() {
		return idField;
	}

	public void setIdField(String idField) {
		this.idField = idField;
	}

	public String getCodeField() {
		return codeField;
	}

	public void setCodeField(String codeField) {
		this.codeField = codeField;
	}

	public String getNameField() {
		return nameField;
	}

	public void setNameField(String nameField) {
		this.nameField = nameField;
	}

	public String getOperatefield() {
		return operatefield;
	}

	public void setOperatefield(String operatefield) {
		this.operatefield = operatefield;
	}

	public Boolean getEnableBaseUrl() {
		return enableBaseUrl;
	}

	public void setEnableBaseUrl(Boolean enableBaseUrl) {
		this.enableBaseUrl = enableBaseUrl;
	}
	

}
